@@ -9,14 +9,12 @@ my $want = $ARGV[0];
 
 my $gps = GPSD::Parse->new;
 
-$gps->on;
-
 my $raw = $gps->poll(return => $want);
 
 # print Dumper $gps->satellites;
 # print Dumper $gps->sky;
 
-my $sat = $gps->satellites(16);
+# my $sat = $gps->satellites(16);
 
 #say $gps->satellites(16, 'el');
 #say $gps->tpv('speed');
@@ -24,5 +22,3 @@ my $sat = $gps->satellites(16);
 #say $gps->device;
 
 print Dumper $raw;
-
-$gps->off;
